@@ -19,8 +19,8 @@
 
 import aeidon
 import gaupol
-_ = aeidon.i18n._
 
+from aeidon.i18n   import _
 from gi.repository import Gtk
 from gi.repository import Pango
 
@@ -31,14 +31,16 @@ class EditorPage(aeidon.Delegate, gaupol.BuilderDialog):
 
     """Editor preferences page."""
 
-    _widgets = ("editor_default_font_check",
-                "editor_font_button",
-                "editor_font_hbox",
-                "editor_length_cell_check",
-                "editor_length_combo",
-                "editor_length_edit_check",
-                "editor_length_hbox",
-                "editor_spell_check_check")
+    _widgets = (
+        "editor_default_font_check",
+        "editor_font_button",
+        "editor_font_hbox",
+        "editor_length_cell_check",
+        "editor_length_combo",
+        "editor_length_edit_check",
+        "editor_length_hbox",
+        "editor_spell_check_check",
+    )
 
     def __init__(self, master, application):
         """Initialize an :class:`EditorPage` instance."""
@@ -125,12 +127,13 @@ class ExtensionPage(aeidon.Delegate, gaupol.BuilderDialog):
 
     """Extension activation and preferences page."""
 
-    _widgets = ("extensions_about_button",
-                "extensions_help_button",
-                "extensions_link_button",
-                "extensions_preferences_button",
-                "extensions_toolbar",
-                "extensions_tree_view")
+    _widgets = (
+        "extensions_about_button",
+        "extensions_help_button",
+        "extensions_preferences_button",
+        "extensions_toolbar",
+        "extensions_tree_view",
+    )
 
     def __init__(self, master, application):
         """Initialize an :class:`ExtensionPage` instance."""
@@ -182,7 +185,6 @@ class ExtensionPage(aeidon.Delegate, gaupol.BuilderDialog):
 
     def _init_values(self):
         """Initialize default values for widgets."""
-        self._link_button.set_uri(gaupol.EXTENSIONS_URL)
         store = self._tree_view.get_model()
         extensions = []
         for module in self.manager.get_modules():
@@ -234,18 +236,9 @@ class ExtensionPage(aeidon.Delegate, gaupol.BuilderDialog):
         module = store[path][0]
         active = store[path][1]
         if active:
-            try:
-                self.manager.teardown_extension(module)
-                gaupol.conf.extensions.active.remove(module)
-            except gaupol.DependencyError:
-                title = _("Cannot deactivate extension")
-                message = _('Extension "{}" is required by other extensions.')
-                message = message.format(store[path][2])
-                dialog = gaupol.ErrorDialog(self._dialog, title, message)
-                dialog.add_button(_("_OK"), Gtk.ResponseType.OK)
-                dialog.set_default_response(Gtk.ResponseType.OK)
-                gaupol.util.flash_dialog(dialog)
-        else: # Activating extension.
+            self.manager.teardown_extension(module)
+            gaupol.conf.extensions.active.remove(module)
+        else:
             self.manager.setup_extension(module)
             gaupol.conf.extensions.active.append(module)
         for row in store:
@@ -272,14 +265,16 @@ class FilePage(aeidon.Delegate, gaupol.BuilderDialog):
 
     """File preferences page."""
 
-    _widgets = ("file_add_button",
-                "file_auto_check",
-                "file_down_button",
-                "file_tree_view",
-                "file_locale_check",
-                "file_remove_button",
-                "file_toolbar",
-                "file_up_button")
+    _widgets = (
+        "file_add_button",
+        "file_auto_check",
+        "file_down_button",
+        "file_locale_check",
+        "file_remove_button",
+        "file_toolbar",
+        "file_tree_view",
+        "file_up_button",
+    )
 
     def __init__(self, master, application):
         """Initialize a :class:`FilePage` instance."""
@@ -305,7 +300,7 @@ class FilePage(aeidon.Delegate, gaupol.BuilderDialog):
         style.add_class(Gtk.STYLE_CLASS_INLINE_TOOLBAR)
         theme = Gtk.IconTheme.get_default()
         # Tool buttons in the UI file are specified as symbolic icons
-        # by name, found in adwaita-icon-theme, if missing in another
+        # by name, found in adwaita-icon-theme. If missing in another
         # theme fall back to non-symbolic icons.
         if not all((theme.has_icon(self._add_button.get_icon_name()),
                     theme.has_icon(self._remove_button.get_icon_name()),
@@ -409,10 +404,12 @@ class PreviewPage(aeidon.Delegate, gaupol.BuilderDialog):
 
     """Preview preferences page."""
 
-    _widgets = ("preview_app_combo",
-                "preview_command_entry",
-                "preview_force_utf_8_check",
-                "preview_offset_spin")
+    _widgets = (
+        "preview_app_combo",
+        "preview_command_entry",
+        "preview_force_utf_8_check",
+        "preview_offset_spin",
+    )
 
     def __init__(self, master, application):
         """Initialize a :class:`PreviewPage` instance."""
@@ -479,12 +476,15 @@ class VideoPage(aeidon.Delegate, gaupol.BuilderDialog):
 
     """Video preferences page."""
 
-    _widgets = ("video_subtitle_bg_check",
-                "video_subtitle_color_button",
-                "video_subtitle_font_button",
-                "video_time_bg_check",
-                "video_time_color_button",
-                "video_time_font_button")
+    _widgets = (
+        "video_seek_spin",
+        "video_subtitle_bg_check",
+        "video_subtitle_color_button",
+        "video_subtitle_font_button",
+        "video_time_bg_check",
+        "video_time_color_button",
+        "video_time_font_button",
+    )
 
     def __init__(self, master, application):
         """Initialize a :class:`PreviewPage` instance."""
@@ -492,8 +492,7 @@ class VideoPage(aeidon.Delegate, gaupol.BuilderDialog):
         self._set_attributes(self._widgets, "video_")
         self.application = application
         self.conf = gaupol.conf.video_player
-        self._init_subtitle_values()
-        self._init_time_values()
+        self._init_values()
 
     def _get_custom_font(self, font):
         """Return custom font as string."""
@@ -503,23 +502,25 @@ class VideoPage(aeidon.Delegate, gaupol.BuilderDialog):
         font_desc.merge(custom_font_desc, True)
         return font_desc.to_string()
 
-    def _init_subtitle_values(self):
-        """Initialize default values for subtitle widgets."""
+    def _init_values(self):
+        """Initialize default values for widgets."""
+        font = self._get_custom_font(self.conf.subtitle_font)
+        self._subtitle_font_button.set_font_name(font)
+        font = self._get_custom_font(self.conf.time_font)
+        self._time_font_button.set_font_name(font)
         self._subtitle_bg_check.set_active(self.conf.subtitle_background)
         color = gaupol.util.hex_to_rgba(self.conf.subtitle_color)
         color.alpha = self.conf.subtitle_alpha
         self._subtitle_color_button.set_rgba(color)
-        font = self._get_custom_font(self.conf.subtitle_font)
-        self._subtitle_font_button.set_font_name(font)
-
-    def _init_time_values(self):
-        """Initialize default values for time widgets."""
         self._time_bg_check.set_active(self.conf.time_background)
         color = gaupol.util.hex_to_rgba(self.conf.time_color)
         color.alpha = self.conf.time_alpha
         self._time_color_button.set_rgba(color)
-        font = self._get_custom_font(self.conf.time_font)
-        self._time_font_button.set_font_name(font)
+        self._seek_spin.set_value(self.conf.seek_length)
+
+    def _on_seek_spin_value_changed(self, spin_button):
+        """Save seek length."""
+        self.conf.seek_length = spin_button.get_value()
 
     def _on_subtitle_bg_check_toggled(self, check_button):
         """Save subtitle background use."""
@@ -568,11 +569,7 @@ class PreferencesDialog(gaupol.BuilderDialog):
         self._preview_page = PreviewPage(self, application)
         self._video_page = VideoPage(self, application)
         self._builder.connect_signals(self._get_callbacks())
-        self.connect("response", self._on_response)
-        aeidon.util.connect(self, "_notebook", "switch-page")
-        self.set_transient_for(parent)
-        self.set_default_response(Gtk.ResponseType.CLOSE)
-        self.set_response_sensitive(Gtk.ResponseType.HELP, False)
+        self._init_dialog(parent)
 
     def _get_callbacks(self):
         """Return a dictionary mapping names to callback methods."""
@@ -587,13 +584,8 @@ class PreferencesDialog(gaupol.BuilderDialog):
                 callbacks[name] = getattr(page, name)
         return callbacks
 
-    def _on_notebook_switch_page(self, notebook, page, index):
-        """Set sensitivity of the help button."""
-        # Use help on the preview page, which is the fourth.
-        self.set_response_sensitive(Gtk.ResponseType.HELP, index == 3)
-
-    def _on_response(self, dialog, response):
-        """Do not send response if browsing help."""
-        if response == Gtk.ResponseType.HELP:
-            gaupol.util.show_uri(gaupol.PREVIEW_HELP_URL)
-            self.stop_emission("response")
+    def _init_dialog(self, parent):
+        """Initialize the dialog."""
+        self.set_default_response(Gtk.ResponseType.CLOSE)
+        self.set_transient_for(parent)
+        self.set_modal(True)
